==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi geri alıyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Geri alma başarısız.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Güncelleme başarısız oldu.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Güncelleme başarısız oldu: yetersiz disk alanı.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>İptal et ve Yeniden başlat</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi geri alıyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Geri alma başarısız.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Güncelleme başarısız oldu.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Güncelleme başarısız oldu: kesintiye uğradı.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Güncellemeler başarısız oldu: DPKG hatası.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Güncelleme başarısız oldu: yetersiz disk alanı.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2&apos;de yedekden %1&apos;e geri dönmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>İptal et ve Yeniden başlat</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
</TS>
